/***** bwt.c **************************************
 * Description: Program for exploring the Burrows-
 *    Wheeler Transform.
 * Reference: D. Adjeroh, T. Bell, and A. 
 *    Mukkherjee (2008). The Burrows-Wheeler Trans-
 *    form; Data Compression, Suffix Arrays, and
 *    Pattern Matching. Springer.
 * Author: Bernhard Haubold, haubold@evolbio.mpg.de
 * Date: Fri Mar  2 08:18:05 2012
 **************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include "interface.h"
#include "eprintf.h"
#include "sequenceData.h"

void scanFile(int fd, Args *args);
void decode(Args *args, Sequence *seq);
void encode(Args *args, Sequence *seq);

int main(int argc, char *argv[]){
  int i;
  char *version;
  Args *args;
  int fd;

  version = "0.3";
  setprogname2("bwt");
  args = getArgs(argc, argv);
  if(args->h || args->e)
    printUsage(version);
  if(args->v)
    printSplash(version);
  if(args->numInputFiles == 0){
    fd = 0;
    scanFile(fd, args);
  }else{
    for(i=0;i<args->numInputFiles;i++){
      fd = open(args->inputFiles[i],0);
      scanFile(fd, args);
      close(fd);
    }
  }
  free(args);
  free(progname());
  return 0;
}

void scanFile(int fd, Args *args){
  Sequence *seq;

  seq = readFasta(fd,args->s);
  if(args->d)
    decode(args, seq);
  else
    encode(args, seq);
  freeSequence(seq);
}
